<?php
/**
 * Partners Section options
 *
 * @package Theme Palace
 * @sub_package Fondness Pro
 * @since Fondness Pro 1.0.0
 */

// Add Partners section
$wp_customize->add_section( 'fondness_pro_partners_section', array(
	'title'             => esc_html__( 'Partners','fondness-pro' ),
	'description'       => esc_html__( 'Partners Section options.', 'fondness-pro' ),
	'panel'             => 'fondness_pro_front_page_panel',
	'active_callback'   => function( $control ) {
        return ( 
        	fondness_pro_is_second_layout( $control )  
        );
    },
) );

// Partners content enable control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[partners_section_enable]', array(
	'default'			=> 	$options['partners_section_enable'],
	'sanitize_callback' => 'fondness_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Fondness_Pro_Switch_Control( $wp_customize, 'fondness_pro_theme_options[partners_section_enable]', array(
	'label'             => esc_html__( 'Partners Section Enable', 'fondness-pro' ),
	'section'           => 'fondness_pro_partners_section',
	'on_off_label' 		=> fondness_pro_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'fondness_pro_theme_options[partners_section_enable]', array(
		'selector'            => '#partners-section .tooltiptext',
		'settings'            => 'fondness_pro_theme_options[partners_section_enable]',
    ) );
}

// Partners content enable control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[partners_autoplay]', array(
	'default'			=> 	$options['partners_autoplay'],
	'sanitize_callback' => 'fondness_pro_sanitize_switch_control',
) );

$wp_customize->add_control( new Fondness_Pro_Switch_Control( $wp_customize, 'fondness_pro_theme_options[partners_autoplay]', array(
	'label'             => esc_html__( 'Partners Logo Autoplay', 'fondness-pro' ),
	'section'           => 'fondness_pro_partners_section',
	'on_off_label' 		=> fondness_pro_switch_options(),
	'active_callback'   => 'fondness_pro_is_partners_section_enable',
) ) );

// Event social icons number control and setting
$wp_customize->add_setting( 'fondness_pro_theme_options[partners_count]', array(
	'default'          	=> $options['partners_count'],
	'sanitize_callback' => 'fondness_pro_sanitize_number_range',
	'validate_callback' => 'fondness_pro_validate_partners_count',
) );

$wp_customize->add_control( 'fondness_pro_theme_options[partners_count]', array(
	'label'             => esc_html__( 'Number of Posts', 'fondness-pro' ),
	'description'       => esc_html__( 'Note: Min 1 & Max 20. Please input the valid number and save. Then refresh the page to see the change.', 'fondness-pro' ),
	'section'           => 'fondness_pro_partners_section',
	'active_callback'   => 'fondness_pro_is_partners_section_enable',
	'type'				=> 'number',
	'input_attrs'		=> array(
		'min'	=> 1,
		'max'	=> 20,
		'style' => 'width: 100px;'
		),
) );

for ( $i = 1; $i <= $options['partners_count']; $i++ ) :

	// Partners image setting and control.
	$wp_customize->add_setting( 'fondness_pro_theme_options[partners_image_' . $i . ']', array(
		'sanitize_callback' => 'fondness_pro_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'fondness_pro_theme_options[partners_image_' . $i . ']',
			array(
			'label'       		=> sprintf( esc_html__( 'Image %d', 'fondness-pro' ), $i),
			'section'     		=> 'fondness_pro_partners_section',
			'active_callback'	=> 'fondness_pro_is_partners_section_enable',
	) ) );

	// Partners url setting and control
	$wp_customize->add_setting( 'fondness_pro_theme_options[partners_url_' . $i . ']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'fondness_pro_theme_options[partners_url_' . $i . ']', array(
		'label'           	=> sprintf( esc_html__( 'Partners Url %d', 'fondness-pro' ), $i),
		'section'        	=> 'fondness_pro_partners_section',
		'active_callback' 	=> 'fondness_pro_is_partners_section_enable',
		'type'				=> 'url',
	) );

endfor;