<?php
/**
 * Partners section
 *
 * This is the template for the content of partners section
 *
 * @package Theme Palace
 * @subpackage Fondness Pro
 * @since Fondness Pro 1.0.0
 */
if ( ! function_exists( 'fondness_pro_add_partners_section' ) ) :
    /**
    * Add partners section
    *
    *@since Fondness Pro 1.0.0
    */
    function fondness_pro_add_partners_section() {
        $options = fondness_pro_get_theme_options();
        // Check if partners is enabled on frontpage
        $partners_enable = apply_filters( 'fondness_pro_section_status', true, 'partners_section_enable' );

        if ( true !== $partners_enable ) {
            return false;
        }

        // Render partners section now.
        fondness_pro_render_partners_section();
    }
endif;

if ( ! function_exists( 'fondness_pro_render_partners_section' ) ) :
  /**
   * Start partners section
   *
   * @return string partners content
   * @since Fondness Pro 1.0.0
   *
   */
   function fondness_pro_render_partners_section() {
        $options = fondness_pro_get_theme_options();

        $autoplay = $options['partners_autoplay'] ? 'true' : 'false';
      
        ?>

        <div id="fondness_pro_partners_section">
        
         <div id="partners-section" class="relative page-section">
                <div class="wrapper">

                <?php if ( is_customize_preview()):
                fondness_pro_section_tooltip( 'partners-section' );
                endif; ?>

                    <div class="section-content  clear" data-slick='{"slidesToShow": 6, "slidesToScroll": 1, "infinite": true, "speed": 1000, "dots": false, "arrows":false, "autoplay": <?php echo esc_attr( $autoplay ); ?>, "draggable": true, "fade": false, "adaptiveHeight": true }'>

                     <?php for ( $i = 1; $i <= $options['partners_count']; $i++){ ?>

                     <?php if( !empty( $options['partners_url_' . $i] ) && !empty( $options['partners_image_' . $i] ) ): ?>

                        <article>

                        <a href="<?php echo esc_url( $options['partners_url_' . $i] ); ?>"><img src="<?php echo esc_url( $options['partners_image_' . $i] ); ?>" alt="partner-<?php echo esc_attr( $i ); ?>"></a>

                        </article>

                        <?php endif; ?>

                        <?php } ?>

                    </div><!-- .section-content -->
                </div><!-- .wrapper -->
            </div>

            </div>
            
    <?php }
endif;